==> uuid-creator-3.7.1-sources.jar: com/github/f4b6a3/uuid/codec/base/function/BaseNDecoder.java <==
/*
 * MIT License
 * 
 * Copyright (c) 2018-2021 Fabio Lima
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.github.f4b6a3.uuid.codec.base.function;

import java.util.UUID;
import java.util.function.Function;

import com.github.f4b6a3.uuid.codec.base.BaseN;
import com.github.f4b6a3.uuid.exception.UuidCodecException;
import com.github.f4b6a3.uuid.util.internal.immutable.LongArray;

/**
 * Abstract function to be extended by all decoder functions of this package.
 * 
 * If the base-n is case insensitive, it decodes in lower case and upper case.
 * 
 * See: https://tools.ietf.org/html/rfc4648
 */
public abstract class BaseNDecoder implements Function<String, UUID> {

	protected final BaseN base;
	protected final LongArray map;

	/**
	 * @param base an enumeration that represents the base-n encoding
	 */
	public BaseNDecoder(BaseN base) {
		this.base = base;
		this.map = base.getMap();
	}

	protected char[] toCharArray(String string) {
		if (string == null) {
			throw new UuidCodecException("Invalid string: null");
		}
		char[] chars = string.toCharArray();
		if (!base.isValid(chars)) {
			throw new UuidCodecException("Invalid string: \"" + string + "\"");
		}
		return chars;
	}
}

==> uuid-creator-4.3.0-sources.jar: com/github/f4b6a3/uuid/codec/base/function/BaseNDecoder.java <==
/*
 * MIT License
 * 
 * Copyright (c) 2018-2021 Fabio Lima
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.github.f4b6a3.uuid.codec.base.function;

import java.util.UUID;
import java.util.function.Function;

import com.github.f4b6a3.uuid.codec.base.BaseN;
import com.github.f4b6a3.uuid.exception.UuidCodecException;
import com.github.f4b6a3.uuid.util.immutable.LongArray;

/**
 * Abstract function to be extended by all decoder functions of this package.
 * 
 * If the base-n is case insensitive, it decodes in lower case and upper case.
 * 
 * See: https://tools.ietf.org/html/rfc4648
 */
public abstract class BaseNDecoder implements Function<String, UUID> {

	protected final BaseN base;
	protected final LongArray map;

	/**
	 * @param base an enumeration that represents the base-n encoding
	 */
	public BaseNDecoder(BaseN base) {
		this.base = base;
		this.map = base.getMap();
	}

	protected char[] toCharArray(String string) {
		if (string == null) {
			throw new UuidCodecException("Invalid string: null");
		}
		char[] chars = string.toCharArray();
		if (!base.isValid(chars)) {
			throw new UuidCodecException("Invalid string: \"" + string + "\"");
		}
		return chars;
	}
}
